@@ -139,12 +139,14 @@ estM <- function(data_CO, data_SS, data_DWP = NULL, frac = 1,
   c_out <- which(rowSums(gDf) == 0)
   if (length(c_out) == 0){
     n <- length(gDf)
-    Mhat <- ((cbinom::rcbinom(n, 1/gDf, gDf)) - (Ecbinom(gDf) - 1))/gDf
+    #Mhat <- ((cbinom::rcbinom(n, 1/gDf, gDf)) - (Ecbinom(gDf) - 1))/gDf
+    Mhat <- (rbinom(n, round(1/gDf), gDf) - (round(1/gDf)*gDf - 1))/gDf
   } else {
     Mhat <- array(0, dim = c(dim(data_CO)[1], nsim))
     gDf <- gDf[-c_out, ]
     n <- length(gDf)
-    Mhat[-c_out,] <- ((cbinom::rcbinom(n, 1/gDf, gDf)) - (Ecbinom(gDf) - 1))/gDf
+    #Mhat[-c_out,] <- ((cbinom::rcbinom(n, 1/gDf, gDf)) - (Ecbinom(gDf) - 1))/gDf
+    Mhat[-c_out, ] <- (rbinom(n, round(1/gDf), gDf) - (round(1/gDf)*gDf - 1))/gDf
   }
   row.names(Mhat) <- row.names(est$ghat)
   out <- list(Mhat = Mhat, Aj = est$Aj, ghat = est$ghat, DWP = est$DWP,
